@@ -43,9 +43,10 @@ class RSS(object):
                                 guid=PyRSS2Gen.Guid(link(request, item['path'])))
               for item in data['files'] ]
     path_link = link(request, data['path'])
-    rss = PyRSS2Gen.RSS2(title=data['title'] or data['path'],
+    description = data.get('title') or data['path']
+    rss = PyRSS2Gen.RSS2(title=description,
                          link=path_link,
-                         description=data['title'] or data['path'],
+                         description=description,
                          lastBuildDate = datetime.datetime.now(),
                          items=items
                          )
