@@ -221,6 +221,8 @@ class Datestamp(FormatterBase):
     def __call__(self, request, data):
         for f in data['files']:
             _datetime = f.get(self.key)
+            if not _datetime:
+                continue
             try:
                 datestamp = _datetime.strftime(self._string)
                 f['datestamp'] = datestamp
