@@ -3,7 +3,7 @@ decoupage: a view with webob to index and serve static content
 """
 
 # TODO:
-# files like `index.ini`
+# handle files with `#`s like like `#index.ini`
 # -> http://k0s.org/portfolio/ideas/#index.ini#
 #
 # oops. Handle it better
@@ -38,7 +38,8 @@ class Decoupage(object):
                  'directory': None, # directory to serve
                  'cascade': 'True', # whether to cascade configuration
                  'template': 'index.html', # XXX see below
-                 'template_directories': '' # list of directories to look for templates
+                 'template_directories': '', # list of directories to look for templates
+                 'charset': 'utf-8', # content encoding for index.html files; -> `Content-Type: text/html; charset=ISO-8859-1`
                  }
 
     def __init__(self, **kw):
@@ -103,7 +104,6 @@ class Decoupage(object):
                                      auto_reload=self.auto_reload)
 
 
-
     ### methods dealing with HTTP
 
     def __call__(self, environ, start_response):
@@ -234,8 +234,13 @@ class Decoupage(object):
                 return self.fileserver(local_index)
             raise
 
+        # set charset if given
+        kw = {}
+        if self.charset:
+            kw['charset'] = self.charset
+
         # return response
-        return Response(content_type='text/html', body=res)
+        return Response(content_type='text/html', body=res, **kw)
 
 
     ### internal methods
